@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 19 May 2012                                              }
+{ last modified: 28 May 2012                                              }
 {*************************************************************************/
 
 #include "containerdialog.h"
@@ -39,6 +39,8 @@ void ContainerDialog::initGui()
     itemsContainer->move(0, 0);
 
     connect(itemsContainer, SIGNAL(onItemClick(QWidget*)), SLOT(onItemClick(QWidget*)));
+    connect(itemsContainer, SIGNAL(onItemDown(QWidget*)), SLOT(onItemDown(QWidget*)));
+    connect(itemsContainer, SIGNAL(onItemUp(QWidget*,bool)), SLOT(onItemUp(QWidget*,bool)));
     connect(itemsContainer,
             SIGNAL(onContextMenu(QWidget*,QContextMenuEvent*)),
             SLOT(onContextMenuShow(QWidget*,QContextMenuEvent*)));
