@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 19 May 2012                                              }
+{ last modified: 28 May 2012                                              }
 {*************************************************************************/
 
 #ifndef CONTAINERDIALOG_H
@@ -49,6 +49,8 @@ protected:
 
 protected slots:
     virtual void onItemClick(QWidget* item){Q_UNUSED(item);}
+    virtual void onItemDown(QWidget* item){Q_UNUSED(item);}
+    virtual void onItemUp(QWidget* item, bool isClicked){Q_UNUSED(item);Q_UNUSED(isClicked);}
     virtual void onContextMenuShow(QWidget* item, QContextMenuEvent *event){Q_UNUSED(item);Q_UNUSED(event);}
 };
 
