@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 29 May 2012                                              }
+{ last modified: 31 May 2012                                              }
 {*************************************************************************/
 
 #ifndef MAINWINDOW_H
@@ -107,7 +107,7 @@ protected:
     OptionsWindow* optionsWindow;
 
     QKineticWidget* itemsContainer;
-    QLabel* labelDir;
+    Label* labelDir;
     KineticListItem* currentFileItem;
     KineticListItem* currentDirItem;
 
